@@ -2,22 +2,24 @@
 #' @include class_definitions.R
 
 
-WorkSheet$methods(initialize = function(showGridLines = TRUE,
-                                        tabSelected = FALSE,
-                                        tabColour = NULL,
-                                        zoom = 100,
-
-                                        oddHeader = NULL,
-                                        oddFooter = NULL,
-                                        evenHeader = NULL,
-                                        evenFooter = NULL,
-                                        firstHeader = NULL,
-                                        firstFooter = NULL,
-
-                                        paperSize = 9,
-                                        orientation = "portrait",
-                                        hdpi = 300,
-                                        vdpi = 300) {
+WorkSheet$methods(initialize = function(
+  showGridLines = TRUE,
+  tabSelected = FALSE,
+  tabColour = NULL,
+  zoom = 100,
+  
+  oddHeader = NULL,
+  oddFooter = NULL,
+  evenHeader = NULL,
+  evenFooter = NULL,
+  firstHeader = NULL,
+  firstFooter = NULL,
+  
+  paperSize = 9,
+  orientation = "portrait",
+  hdpi = 300,
+  vdpi = 300
+  ) {
   if (!is.null(tabColour)) {
     tabColour <- sprintf('<sheetPr><tabColor rgb="%s"/></sheetPr>', tabColour)
   } else {
@@ -39,16 +41,25 @@ WorkSheet$methods(initialize = function(showGridLines = TRUE,
     })
   }
 
+  # hf <- list(
+  #   oddHeader = naToNULLList(oddHeader),
+  #   oddFooter = naToNULLList(oddFooter),
+  #   evenHeader = naToNULLList(evenHeader),
+  #   evenFooter = naToNULLList(evenFooter),
+  #   firstHeader = naToNULLList(firstHeader),
+  #   firstFooter = naToNULLList(firstFooter)
+  # )
+  
   hf <- list(
-    oddHeader = naToNULLList(oddHeader),
-    oddFooter = naToNULLList(oddFooter),
-    evenHeader = naToNULLList(evenHeader),
-    evenFooter = naToNULLList(evenFooter),
-    firstHeader = naToNULLList(firstHeader),
-    firstFooter = naToNULLList(firstFooter)
+    oddHeader   = oddHeader,
+    oddFooter   = oddFooter,
+    evenHeader  = evenHeader,
+    evenFooter  = evenFooter,
+    firstHeader = firstHeader,
+    firstFooter = firstFooter
   )
-
-  if (all(sapply(hf, length) == 0)) {
+  
+  if (all(vapply(hf, is.null, NA))) {
     hf <- list()
   }
 
@@ -56,7 +67,7 @@ WorkSheet$methods(initialize = function(showGridLines = TRUE,
   sheetPr <<- tabColour
   dimension <<- '<dimension ref="A1"/>'
   sheetViews <<- sprintf('<sheetViews><sheetView workbookViewId="0" zoomScale="%s" showGridLines="%s" tabSelected="%s"/></sheetViews>', as.integer(zoom), as.integer(showGridLines), as.integer(tabSelected))
-  sheetFormatPr <<- '<sheetFormatPr defaultRowHeight="15.0"/>'
+  sheetFormatPr <<- '<sheetFormatPr defaultRowHeight="15.0" baseColWidth="10"/>'
   cols <<- character(0)
 
   autoFilter <<- character(0)
@@ -84,14 +95,8 @@ WorkSheet$methods(initialize = function(showGridLines = TRUE,
 
 
 
-
-
-
-
-
-
 WorkSheet$methods(get_prior_sheet_data = function() {
-  xml <- '<worksheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:xdr="http://schemas.openxmlformats.org/drawingml/2006/spreadsheetDrawing" xmlns:x14="http://schemas.microsoft.com/office/spreadsheetml/2009/9/main" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" mc:Ignorable="x14ac" xmlns:x14ac="http://schemas.microsoft.com/office/spreadsheetml/2009/9/ac">'
+  xml <- '<worksheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main" xmlns:r="http://schemas.openxmlformats.org/officeDocument/2006/relationships" xmlns:xdr="http://schemas.openxmlformats.org/drawingml/2006/spreadsheetDrawing" xmlns:x14="http://schemas.microsoft.com/office/spreadsheetml/2009/9/main" xmlns:mc="http://schemas.openxmlformats.org/markup-compatibility/2006" mc:Ignorable="x14ac xr xr2 xr3" xmlns:x14ac="http://schemas.microsoft.com/office/spreadsheetml/2009/9/ac" xmlns:xr="http://schemas.microsoft.com/office/spreadsheetml/2014/revision" xmlns:xr2="http://schemas.microsoft.com/office/spreadsheetml/2015/revision2" xmlns:xr3="http://schemas.microsoft.com/office/spreadsheetml/2016/revision3">'
 
   if (length(sheetPr) > 0) {
     tmp <- sheetPr
@@ -126,8 +131,6 @@ WorkSheet$methods(get_prior_sheet_data = function() {
 })
 
 
-
-
 WorkSheet$methods(get_post_sheet_data = function() {
   xml <- ""
 
@@ -143,8 +146,6 @@ WorkSheet$methods(get_post_sheet_data = function() {
     xml <- paste0(xml, paste0(sprintf('<mergeCells count="%s">', length(mergeCells)), pxml(mergeCells), "</mergeCells>"), collapse = "")
   }
 
-
-
   if (length(conditionalFormatting) > 0) {
     nms <- names(conditionalFormatting)
     xml <- paste0(xml,
@@ -167,14 +168,11 @@ WorkSheet$methods(get_post_sheet_data = function() {
     xml <- paste0(xml, paste0(sprintf('<dataValidations count="%s">', length(dataValidations)), pxml(dataValidations), "</dataValidations>"))
   }
 
-
-
   if (length(hyperlinks) > 0) {
-    h_inds <- paste0(1:length(hyperlinks), "h")
-    xml <- paste(xml, paste("<hyperlinks>", paste(sapply(1:length(h_inds), function(i) hyperlinks[[i]]$to_xml(h_inds[i])), collapse = ""), "</hyperlinks>"), collapse = "")
+    h_inds <- paste0(seq_along(hyperlinks), "h")
+    xml <- paste(xml, paste("<hyperlinks>", paste(sapply(seq_along(h_inds), function(i) hyperlinks[[i]]$to_xml(h_inds[i])), collapse = ""), "</hyperlinks>"), collapse = "")
   }
 
-
   if (length(pageMargins) > 0) {
     xml <- paste0(xml, pageMargins, collapse = "")
   }
@@ -183,11 +181,10 @@ WorkSheet$methods(get_post_sheet_data = function() {
     xml <- paste0(xml, pageSetup, collapse = "")
   }
 
-  if (length(headerFooter) > 0) {
+  if (!identical(headerFooter, list()) && length(headerFooter) > 0) {
     xml <- paste0(xml, genHeaderFooterNode(headerFooter), collapse = "")
   }
 
-
   ## rowBreaks and colBreaks
   if (length(rowBreaks) > 0) {
     xml <- paste0(xml,
@@ -196,7 +193,6 @@ WorkSheet$methods(get_post_sheet_data = function() {
     )
   }
 
-
   if (length(colBreaks) > 0) {
     xml <- paste0(xml,
       paste0(sprintf('<colBreaks count="%s" manualBreakCount="%s">', length(colBreaks), length(colBreaks)), paste(colBreaks, collapse = ""), "</colBreaks>"),
@@ -204,14 +200,6 @@ WorkSheet$methods(get_post_sheet_data = function() {
     )
   }
 
-
-
-
-
-
-
-
-
   if (length(drawing) > 0) {
     xml <- paste0(xml, drawing, collapse = "")
   }
